OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Указанное название слишком длинное",
    "The given web address is too long" : "Указанный веб-адрес слишком длинный",
    "The given web address is not a valid URL" : "Указанный веб-адрес не является действительным URL",
    "The given legal notice address is too long" : "Указанный адрес на официальное уведомление слишком длинный",
    "The given legal notice address is not a valid URL" : "Указанный адрес на официальное уведомление не является действительным URL",
    "The given privacy policy address is too long" : "Указанный адрес политики конфиденциальности слишком длинный",
    "The given privacy policy address is not a valid URL" : "Указанный адрес политики конфиденциальности не является действительным URL",
    "The given slogan is too long" : "Указанный слоган слишком длинный",
    "The given color is invalid" : "Задан неправильный цвет",
    "Disable-user-theming should be true or false" : "Disable-user-theming должен быть true или false",
    "Saved" : "Сохранено",
    "Invalid app given" : "Указано неверное приложение.",
    "Invalid type for setting \"defaultApp\" given" : "Указан неверный тип для настройки \"defaultApp\"",
    "Invalid setting key" : "Неверный ключ настройки",
    "The file was uploaded" : "Файл был загружен",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Размер переданного файла превышает установленный предел upload_max_filesize в php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Размер переданного файла превышает установленный предел MAX_FILE_SIZE в HTML-форме",
    "The file was only partially uploaded" : "Файл был получен частично",
    "No file was uploaded" : "Не было отправлено ни одного файла",
    "Missing a temporary folder" : "Отсутствует временный каталог",
    "Could not write file to disk" : "Невозможно записать файл на диск",
    "A PHP extension stopped the file upload" : "Расширение PHP прервало загрузку файла",
    "No file uploaded" : "Нет загруженных файлов",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Вы уже используете настраиваемое оформление, которое может быть перезаписано этим приложением.",
    "Theming" : "Внешний вид",
    "Appearance and accessibility" : "Внешний вид и доступность",
    "PHP Imagick module" : "PHP модуль Imagick",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Для создания значка favicon приложением «Оформления» необходимо установить и активировать модуль «imagic» подсистемы PHP. ",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Модуль PHP \"imagick\" в данном случае не имеет поддержки SVG. Для лучшей совместимости рекомендуется его установить.",
    "Dark theme with high contrast mode" : "Темная тема с режимом высокой контрастности",
    "Enable dark high contrast mode" : "Включить темную тему в режиме высокой контрастности",
    "Similar to the high contrast mode, but with dark colours." : "Аналогично режиму высокой контрастности, но с использованием темных цветов.",
    "Dark theme" : "Тёмное оформление",
    "Enable dark theme" : "Использовать тёмное оформление",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Темная тема для облегчения работы ваших глаз за счет уменьшения общей яркости.",
    "System default theme" : "Системная тема по умолчанию",
    "Enable the system default" : "Включить системную тему по умолчанию",
    "Using the default system appearance." : "Используется внешний вид системы по умолчанию.",
    "Dyslexia font" : "Шрифт Dyslexia",
    "Enable dyslexia font" : "Использовать шрифт Dyslexia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic — бесплатный шрифт, который смягчает некоторые распространённые ошибки чтения, вызываемые дислексией.",
    "High contrast mode" : "Режим высокой контрастности",
    "Enable high contrast mode" : "Включить режим высокой контрастности",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Этот режим делает ярлыки и кнопки меню более чёткими за счёт уменьшения качества.",
    "Light theme" : "Светлая тема",
    "Enable the default light theme" : "Включить светлую тему по умолчанию",
    "The default light appearance." : "Подсветка по умолчанию.",
    "Legal notice" : "Официальное уведомление",
    "Privacy policy" : "Политика конфиденциальности",
    "Adjust the Nextcloud theme" : "Скорректируйте тему Nextcloud'а",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Этот модуль позволяют настроить внешний вид сервера и поддерживаемых клиентов. Настройки, определённые в этом модуле, распространяются на всех пользователей.",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Вместо фонового изображения вы также можете настроить простой цвет фона. Если вы используете фоновое изображение, изменение этого цвета повлияет на цвет иконок меню приложения.",
    "Background color" : "Цвет фона",
    "Upload new logo" : "Загрузить новый логотип",
    "Logo" : "Логотип",
    "Upload new background and login image" : "Загрузите новое фоновое изображение и изображение для входа в систему",
    "Background and login image" : "Фоновое изображение и изображение входа в систему",
    "Advanced options" : "Дополнительные параметры",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Для автоматической генерации favicon на основе загруженного логотипа и цвета нужно установить PHP расширение ImageMagick  с поддержкой изображений SVG ",
    "Name" : "Название",
    "Web link" : "Ссылка",
    "a safe home for all your data" : "надёжный дом для всех ваших данных",
    "Slogan" : "Слоган",
    "Primary color" : "Основной цвет",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Основной цвет используется для выделения таких элементов, как важные кнопки. Он может быть немного изменен в зависимости от текущей цветовой схемы.",
    "Legal notice link" : "Ссылка на официальное уведомление",
    "Privacy policy link" : "Ссылка на политику конфиденциальности",
    "Header logo" : "Логотип заголовка",
    "Upload new header logo" : "Загрузить логотип заголовка",
    "Favicon" : "Favicon (значок сайта)",
    "Upload new favicon" : "Загрузить значок сайта",
    "User settings" : "Параметры пользователя",
    "Disable user theming" : "Отключить выбор темы для пользователей",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Хотя вы можете выбрать и настроить свой экземпляр, пользователи могут изменять свой фон и цвета. Если вы хотите принудительно применить свои настройки для всех, вы можете включить это.",
    "Appearance and accessibility settings" : "Внешний вид и доступность",
    "Misc accessibility options" : "Различные параметры специальных возможностей",
    "Enable blur background filter (may increase GPU load)" : "Включить фильтр размытия фона (может увеличить нагрузку на графический процессор)",
    "Customization has been disabled by your administrator" : "Настройка тем была отключена вашим администратором",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Выберите основной цвет, чтобы выделить важные элементы. Цвет, используемый для таких элементов, как основные кнопки, может немного отличаться при настройке в соответствии с требованиями к доступности.",
    "Background and color" : "Фон и цвет",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "В качестве фона можно выбрать изображение из набора по умолчанию, пользовательское загруженное изображение или обычный цвет.",
    "Keyboard shortcuts" : "Сочетания клавиш",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "В некоторых случаях сочетания клавиш могут мешать работе инструментов специальных возможностей. Чтобы правильно сфокусироваться на вашем инструменте, вы можете отключить здесь все сочетания клавиш. Это также отключит все доступные ярлыки в приложениях.",
    "Disable all keyboard shortcuts" : "Отключить все сочетания клавиш",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Доступная среда очень важна для нас. При разработке мы следуем веб-стандартам, контролируя возможность пользования всем сервисом без помощи мыши и с использованием вспомогательных программ, например, выполняющих чтение с экрана. Мы стремимся к выполнению рекомендаций {guidelines}Руководства доступности Веб-Контента{linkend} 2.1 на уровне АА, а при использовании режима высокой контрастности  — даже на уровне ААА.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "При обнаружении ошибок, не стесняйтесь сообщать о них {issuetracker}на наш форум{linkend}. Если Вы заинтересованы в продвижении проекта присоединяйтесь к {designteam}нашей команде дизайнеров{linkend}!",
    "Current selected app: {app}, position {position} of {total}" : "Текущее выбранное приложение: {app}, позиция {position} из {total}",
    "Move up" : "Переместить выше",
    "Move down" : "Переместить ниже",
    "Custom background" : "Пользовательский фон",
    "Plain background" : "Обычный фон",
    "Default background" : "Фоновое изображение по умолчанию",
    "Select a background from your files" : "Выберите фон из ваших файлов",
    "Select background" : "Выбрать фоновое изображение",
    "No background has been selected" : "Фоновое изображение не было выбрано",
    "Theme selection is enforced" : "Выбор темы принудительно",
    "Navigation bar settings" : "Параметры панели навигации",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Вы можете настроить порядок приложений в панели навигации. Первая запись будет приложением по умолчанию, и будет открываться после авторизации или при нажатии на логотип.",
    "The default app can not be changed because it was configured by the administrator." : "Приложение по умолчанию не может быть изменено, поскольку оно настроено администратором.",
    "The app order was changed, to see it in action you have to reload the page." : "Порядок приложений изменен, чтобы увидеть изменения необходимо перезагрузить страницу.",
    "Reset default app order" : "Восстановить порядок приложений",
    "Could not set the app order" : "Не удалось изменить порядок приложений",
    "Could not reset the app order" : "Не удалось восстановить порядок приложений",
    "Reset primary color" : "Сброс основного цвета",
    "Could not set primary color" : "Не удалось установить основной цвет",
    "Default app" : "Приложение по умолчанию",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Приложение по умолчанию - это приложение, которое открывается, например, после входа в систему или при нажатии на логотип в меню.",
    "Use custom default app" : "Использовать пользовательское приложение по умолчанию",
    "Global default app" : "Глобальное приложение по умолчанию",
    "Global default apps" : "Глобальные приложения по умолчанию",
    "Default app priority" : "Приоритет приложения по умолчанию",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Если приложение не включено для пользователя, используется следующее приложение с более низким приоритетом.",
    "Could not set global default apps" : "Не удалось установить глобальные приложения по умолчанию.",
    "Select a custom color" : "Выберать собственный цвет",
    "Reset to default" : "Сбросить изменения",
    "Upload" : "Отправить",
    "Remove background image" : "Убрать фоновое изображение ",
    "Color" : "Цвет",
    "Background" : "Фон",
    "Set a custom background" : "Установить пользовательский фон",
    "Change color" : "Изменить цвет",
    "No background" : "Без фона"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
